@@ -1,4 +1,5 @@
 test_that("A brain volume for a single subject can be loaded", {
+    testthat::skip_on_cran(); # skip: leads to memory errors ('cannot allocate vector of size XX MB') on CRAN.
     skip_if(tests_running_on_cran_under_macos(), message = "Skipping on CRAN under MacOS, required test data cannot be downloaded.");
     fsbrain::download_optional_data();
     subjects_dir = fsbrain::get_optional_data_filepath("subjects_dir");
@@ -6,8 +7,10 @@ test_that("A brain volume for a single subject can be loaded", {
 
     subject_id = "subject1";
     brain = subject.volume(subjects_dir, subject_id, 'brain');
+    brain2 = subject.volume(subjects_dir, subject_id, 'brain', format = 'mgz');
 
     expect_equal(dim(brain), c(256, 256, 256));
+    expect_equal(dim(brain2), c(256, 256, 256));
 
     # Extract a single slice (2D image) from the volume
     slice = vol.slice(brain, 128);
@@ -19,6 +22,9 @@ test_that("A brain volume for a single subject can be loaded", {
 
     # Load the slice into image magick (need to adjust color range)
     #img = magick::image_read(grDevices::as.raster(slice / 255));
+
+    # error handling
+    testthat::expect_error(subject.volume(subjects_dir, subject_id, 'brain', format = "nosuchformat"));   # invalid format
 })
 
 
@@ -68,10 +74,40 @@ test_that("Brain volume CRS voxels are rendered at the correct surface space RAS
      # It shows that the brain surface lies within the volume boundaries, and the bounding box from the volume fits.
 
      expect_equal(1L, 1L);   # empty tests will be skipped
+
+     # error handling
+     expect_error(vol.vox.from.crs(fs_crs = "dunno")); # fs_crs must be numeric
+})
+
+
+test_that("The tkr vox2ras can be retrieved", {
+    r2v = ras2vox_tkr();
+    expect_true(is.matrix(r2v));
+})
+
+
+test_that("Voxel transform can be computed", {
+
+    # with vector
+    fs_crs = c(0L, 0L, 0L);
+    r_ind_eucli = vol.vox.from.crs(fs_crs);
+    r_ind_homog = vol.vox.from.crs(fs_crs, add_affine = TRUE);
+
+    testthat::expect_true(is.vector(r_ind_eucli));
+    testthat::expect_true(is.vector(r_ind_homog));
+
+    # with matrix
+    fs_crs_matrix = matrix(seq(6L), ncol = 3L, byrow = TRUE);
+    r_ind_eucli_mat = vol.vox.from.crs(fs_crs_matrix);
+    r_ind_homog_mat = vol.vox.from.crs(fs_crs_matrix, add_affine = TRUE);
+
+    testthat::expect_true(is.matrix(r_ind_eucli_mat));
+    testthat::expect_true(is.matrix(r_ind_homog_mat));
 })
 
 
 test_that("The loaded brain volume is in the correct orientation and the fs CRS to R CRS transformation works", {
+    testthat::skip_on_cran(); # skip: leads to memory errors ('cannot allocate vector of size XX MB') on CRAN.
     skip_if(tests_running_on_cran_under_macos(), message = "Skipping on CRAN under MacOS, required test data cannot be downloaded.");
     fsbrain::download_optional_data();
     subjects_dir = fsbrain::get_optional_data_filepath("subjects_dir");
